@@ -22,11 +22,11 @@ Text::Amuse::Compile - Compiler for Text::Amuse
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 =head1 SYNOPSIS
 
@@ -228,23 +228,8 @@ sub standalone {
 
 
 sub extra {
-    my $self = shift;
-    my $hashref = $self->{extra};
-    my %out;
-    # do a shallow copy before returning, filtering out special chars
-    # to avoid command injections.
-    my $specials = qr/[\\\$\&\{\}_\^%\#~]/;
-    if ($hashref) {
-        foreach my $k (keys %$hashref) {
-            my $v = $hashref->{$k};
-            if (defined($v) and $v =~ m/$specials/) {
-                warn "Found special character in $v in extra key $k, stripping\n";
-                $v =~ s/$specials//g;
-            }
-            $out{$k} = $v;
-        }
-    }
-    return %out;
+    my $extra = shift->{extra} || {};
+    return %$extra;
 }
 
 =head2 METHODS
