@@ -51,44 +51,60 @@ Muse headers).
 Minimal (but valid) XHTML template, with a link to C<stylesheet.css>.
 Meant to be used in the EPUB generation.
 
-=head3 latex
-
-The LaTeX template, with dimension conditional.
-
-The built-in LaTeX template supports the following options (they are
-passed B<verbatim> and B<unescaped>, so it's your responsibility to
-filter out garbage in an exposed environment (such a web interface).
-
 =head3 bare_latex
 
 Minimal and uncomplete LaTeX chunck, meant to be used when merging
 files.
 
+=head3 latex
+
+The LaTeX template, with dimension conditional.
+
+The built-in LaTeX template supports the following options, which are
+picked up from the C<extra> constructor of L<Text::Amuse::Compile>.
+
+The template itself uses two hashrefs with tokens: C<options> and
+C<safe_options>. The C<options> contains tokens which are interpreted
+as L<Text::Amuse> strings from the C<extra> constructor. The
+C<safe_options> ones contains validate copies of the C<options> for
+places where it make sense, plus some internal things like the
+languages and additional strings to get the LaTeX code right.
+
+All the values from C<options> and C<safe_options>, because of the
+markup interpretation, are (hopefully) safely escaped (so you can pass
+even LaTeX commands, and they will be escaped).
+
 =head4 Globals
 
 =over 4
 
-=item options.nocoverpage
+=item safe_options.nocoverpage
 
 If the text doesn't require a toc, this options set the class to
 komascript's article. Ignored if there is a toc.
 
-=item options.notoc
+=item safe_options.notoc
 
 Do not generate a table of contents, even if the document requires
 one.
 
-=item options.papersize
+=item safe_options.papersize
 
 Paper size, like a4, a5 or 210mm:11in. The width and heigth are
 swapped in some komascript version. Just keep this in mind and do some
 trial and error if you need custom dimensions.
 
-=item options.division
+=item safe_options.division
 
 The DIV of the C<typearea> package. Defaults to 12. Go and read the doc.
 
-=item options.bcor
+=item safe_options.opening
+
+On which pages the chapters should open: right, left, any. Default:
+right. The left one will probably lead to unexpected results (the PDF
+will start with an empty page), so use it at your own peril.
+
+=item safe_options.bcor
 
 The BCOR of the C<typearea> package. Defaults to 0mm. Go and read the doc.
 It expects a TeX dimension like 10mm or 1in or 1.2cm.
@@ -97,15 +113,16 @@ B<Please note that this has no effect on the plain PDF output>, as we,
 opinionately, force BCOR=0mm and oneside=true for this kind of output.
 But, of course, it does affect the imposed output.
 
-=item options.fontsize
+=item safe_options.fontsize
 
 The font size in point (should be an integer). Defaults to 10.
 
-=item options.mainfont
+=item safe_options.mainfont
 
 The system font name, such as C<Linux Libertine O> or C<Charis SIL>.
 This implementation uses XeLaTeX, so we can use system fonts. Defaults
-to C<Linux Libertine O>.
+to C<Linux Libertine O>. This is just a copy of C<options.mainfont>,
+as we can't know which font is installed.
 
 =item options.oneside
 
@@ -119,6 +136,11 @@ B<Please note that this has no effect on the plain PDF output>, as we,
 opinionately, force BCOR=0mm and oneside=true for this kind of output.
 But, of course, it does affect the imposed output.
 
+=item safe_options.paging
+
+The merging of C<options.oneside> and C<options.twoside> results in
+this token. If both or none are true, will default to C<oneside>.
+
 =back
 
 =head4 Cover
@@ -131,7 +153,7 @@ When this option is set to a true value, skip the creation of the
 title page with \maketitle, and instead build a custome one, with the
 cover placed in the middle of the page.
 
-=item options.coverwidth
+=item safe_options.coverwidth
 
 Option to control the cover width, when is set (ignored otherwise).
 Defaults to the full text width (i.e., 1). You have to pass a float
@@ -563,11 +585,11 @@ sub latex {
         return $ref;
     }
     my $latex = <<'EOF';
-\documentclass[DIV=[% safe_options.division -%],%
-               BCOR=[% safe_options.bcor -%],%
+\documentclass[DIV=[% safe_options.division %],%
+               BCOR=[% safe_options.bcor %],%
+               footinclude=false,[% IF safe_options.opening %]open=[% safe_options.opening %],[% END %]%
                fontsize=[% safe_options.fontsize %]pt,%
                [% safe_options.paging %],%
-               footinclude=false,%
                paper=[% safe_options.papersize %]]%
                {[% safe_options.class %]}
 \usepackage{fontspec}
